summaryrefslogtreecommitdiff
path: root/include/cros_board_info.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/cros_board_info.h')
-rw-r--r--include/cros_board_info.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/cros_board_info.h b/include/cros_board_info.h
index a8a1d5c023..ca5dc34d0a 100644
--- a/include/cros_board_info.h
+++ b/include/cros_board_info.h
@@ -44,8 +44,8 @@ struct cbi_data {
/**
* Board info accessors
*
* @param version/sku_id/oem_id/id/fw_config/pcb_supplier [OUT] Data read from
* EEPROM
* @return EC_SUCCESS on success or EC_ERROR_* otherwise.
*/
int cbi_get_board_version(uint32_t *version);
@@ -54,6 +54,7 @@ int cbi_get_oem_id(uint32_t *oem_id);
int cbi_get_model_id(uint32_t *id);
int cbi_get_fw_config(uint32_t *fw_config);
int cbi_get_pcb_supplier(uint32_t *pcb_supplier);
+int cbi_get_ssfc(uint32_t *ssfc);
/**
* Primitive accessors
@@ -44,8 +44,8 @@ struct cbi_data {
* Board info accessors
*
- * @param version/sku_id/oem_id/id/fw_config/pcb_supplier [OUT] Data read from
- * EEPROM
+ * @param version/sku_id/oem_id/id/fw_config/pcb_supplier/ssfc [OUT] Data read
+ * from EEPROM
* @return EC_SUCCESS on success or EC_ERROR_* otherwise.
*/